# grouponefunctions

A package containing the necessary functions to smoothly run the analysis in DSCI-310-Group-1

## Installation

```bash
$ pip install grouponefunctions
```

## Usage

- The package has three functions: splitxy, listfun, and plotsquaredata. 

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`grouponefunctions` was created by Andres Zepeda Perez, Daniel Hou, Zizhen Guo, Timothy Zhou. It is licensed under the terms of the MIT license.

## Credits

`grouponefunctions` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
